@@ -76,7 +76,7 @@ class GuestInvitation(AbstractBaseInvitation):
                               max_length=app_settings.EMAIL_MAX_LENGTH)
     created = models.DateTimeField(verbose_name=_('created'),
                                    default=timezone.now)
-    authorentity = ForeignKeyOptional(settings.INVITATIONS_AUTHOR_MODEL)
+    authorentity = models.IntegerField('author',null=True,blank=True)
 
     @classmethod
     def create(cls, email, inviter=None, authorentity=None,  **kwargs):
